function restorex, savefile, xname

; This function extracts a specified variable from an IDL saveset
; The return value is the restored variable. Note that the name given the 
; the returned variable is independent of the name in the save set. 

; INPUT:
; savefile = name of IDL saveset. [string]
; xname = name of IDL variable to restore. [string]
;
; Both inputs must be scalars (or 1-element arrays).

; Examples:
;
; We want to restore one variable, X, from a saveset:
; IDL> X = restorex('saveset.dat','X')
;
; We want to restore a scalar integer, M, from three different savesets, and
; save the result in an array, N.
; IDL> files = ['saveset1.dat','saveset2.dat','saveset3.dat']
; IDL> N = intarr(3)
; IDL> for i=0,2 do N[i] = restorex(files[i],'M')



; HISTORY
; 2011-04-21:  Version 0.9, R. Arendt, rick.arendt@nasa.gov
on_error,2

(obj_new('IDL_savefile',savefile))->restore,xname

status = execute('x = temporary('+xname+')')
return,x

end
  
